<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Prehliadač obrázkov</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Verzia:</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Deepin Prehliadač obrázkov je módny a plynulý manažér obrázkov.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Obsahuje správu obrázkov, prezeranie obrázkov a základnú úpravu obrázkov.</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>obrázok</translation>
    </message>
    <message>
        <source>images</source>
        <translation>obrázky</translation>
    </message>
    <message>
        <source>album</source>
        <translation>album</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>albumy</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Správa synchronizácie</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Synchronizácia:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nový album</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Nepomenované</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Posledné importované</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje obľúbené</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Naozaj chcete vymazať tento album?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Odstrániť</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Späť</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje obľúbené</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Časová os</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pridať</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Môžete pridať synchronizáciu priečinka alebo pretiahnuť a pustiť obrázky do časovej osi</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Nepomenované</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Náhľad</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Sled snímkov</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Odstrániť</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Prehliadač obrázkov</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Obrázky</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Naozaj chcete pridať obrázky do albumu?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Synchronizovať a vytvoriť</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Synchronizovať</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Naozaj chcete pridať do zoznamu synchronizácie a vytvoriť album pomenovaný po tejto zložke?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Exportovanie úspešné</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Exportovanie zlyhalo</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložiť</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Naozaj chcete hodiť fotografie do KOŠA?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Odstrániť</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Informácie o obrázku</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Tento súbor obsahuje viac stránok, použite prosím Evince na zobrazenie všetkých stránok.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Náhľad</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Sled snímkov</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tlač</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovanie</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Skopírovať do schránky</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Hodiť do koša</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstrániť z albumu</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Obľúbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neobľúbené</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočiť v smere hodinových ručičiek</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočiť proti smeru hodinových ručičiek</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastaviť ako pozadie</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobraziť v správcovi súborov</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informácie o obrázku</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pridať</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Môžete pridať synchronizáciu priečinka alebo pretiahnuť a pustiť obrázky do časovej osi</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Pridať do albumu</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Pridať do nového albumu</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Otvoriť adresár</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nemáte povolenie na zobrazenie tohto obrázka</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Dátum fotografovania</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Dátum úpravy</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Rozlíšenie</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Veľkosť súboru</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Farebný priestor</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Režim expozície</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program expozície</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Čas expozície</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blesk</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Clona</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Ohnisková vzdialenosť</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Maximálna clona</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Režim merania</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Vyváženie bielej</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Korekcia zábleskovej expozície</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model fotoaparátu</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model objektívu</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Žiadne škálovanie</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Prispôsobiť stránku obrázku</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Prispôsobiť obrázok na stránku</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Škálovať na:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milimetre</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centimetre</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Palce</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Pozícia obrázku</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Škálovanie</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Nastavenia obrázku</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Uzávierka</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Spínač</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Sled snímkov</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Prsteň</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Výber adresára</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Tento priečinok je zakázany pre synchronizáciu</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Pridať priečinok</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Správa synchronizácie priečinka</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Zoznam adresára je prázdny</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Zrušiť synchronizáciu</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Zariadenie bolo odstránené</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Tento priečinok už neexistuje</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Prepočítavam...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Zobrazenie obrázkov</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Náhľad</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Sled snímkov</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Ukončiť sled obrázkov</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Hodiť do koša</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstrániť z albumu</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Obľúbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neobľúbené</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočiť v smere hodinových ručičiek</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočiť proti smeru hodinových ručičiek</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastaviť ako pozadie</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobraziť v správcovi súborov</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informácie o obrázku</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Predchádzajúca</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Ďalej</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Predchádzajúca obrazovka</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Ďalšia obrazovka</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nový album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončiť</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazenie skratiek</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Prosím zadajte novú skratku</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Skratky</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Náhľad obrázka</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Obnoviť predvolené</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Náhľad</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Sled snímkov</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Ukončiť sled obrázkov</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tlač</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Hodiť do koša</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstrániť z albumu</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Obľúbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neobľúbené</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočiť v smere hodinových ručičiek</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočiť proti smeru hodinových ručičiek</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastaviť ako pozadie</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobraziť v správcovi súborov</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informácie o obrázku</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nový album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Odstrániť</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Ukončiť sled obrázkov</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Pauza/Prehrať</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Nastavenia sledu snímkov</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Zmeniť efekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Trvanie</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Zmeniť rozsah</translation>
    </message>
    <message>
        <source>second</source>
        <translation>sekunda</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Späť</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Správa obrázkov</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje obľúbené</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Veľkosť 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Prispôsobiť oknu</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočiť proti smeru hodinových ručičiek</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočiť v smere hodinových ručičiek</translation>
    </message>
    <message>
        <source>Throw to Trash</source>
        <translation>Hodiť do koša</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neobľúbené</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Obľúbené</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Neboli nájdené žiadne súbory obrázkov</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 obrázok</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 obrázky</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Správa synchronizácie</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Synchronizácia:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pridať</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Môžete pridať synchronizáciu priečinka alebo pretiahnuť a pustiť obrázky do časovej osi</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Pridať do albumu</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Pridať do nového albumu</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Náhľad</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Sled snímkov</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tlač</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Skopírovať do schránky</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Hodiť do koša</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Obľúbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neobľúbené</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočiť v smere hodinových ručičiek</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočiť proti smeru hodinových ručičiek</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastaviť ako pozadie</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobraziť v správcovi súborov</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informácie o obrázku</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Nastavenia sledu snímkov</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Trvanie</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skratky</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Náhľad</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM rrrr</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje obľúbené</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Posledné importované</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nový album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Deepin Prehliadač obrázkov je módny a plynulý manažér obrázkov.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Obsahuje správu obrázkov, prezeranie obrázkov a základnú úpravu obrázkov.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tmavá téma</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Časová os</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Pridať do albumu</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Pridať do nového albumu</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Ukončiť celú obrazovku</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Sled snímkov</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tlač</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Skopírovať do schránky</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Hodiť do koša</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstrániť z albumu</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Obľúbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neobľúbené</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Zobraziť okno navigácie</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Skryť okno navigácie</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočiť v smere hodinových ručičiek</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočiť proti smeru hodinových ručičiek</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastaviť ako pozadie</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobraziť v správcovi súborov</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informácie o obrázku</translation>
    </message>
</context>
</TS>